#' @title Gaussian process modelling in greta
#' @name greta.gp
#'
#' @description A greta module to create and combine covariance functions and
#'   use them to build Gaussian process models in greta. See
#'   [kernels()] and [gp()]
#'
#' @importFrom greta .internals
#' @importFrom tensorflow tf
#'
"_PACKAGE"
